This is a library to allow communicating to a Midea AC via the Local area network.

# midea-msmart

This a mirror from the repo at [NeoAcheron/midea-ac-py](https://github.com/NeoAcheron/midea-ac-py).

But this library just allow communicating to a Midea AC via the Local area network, not via the Midea Cloud yet.

Thanks for [yitsushi's project](https://github.com/yitsushi/midea-air-condition), [NeoAcheron's project](https://github.com/NeoAcheron/midea-ac-py), [andersonshatch's project](https://github.com/andersonshatch/midea-ac-py).